<?php

namespace Labrender\Outh2API\Http\Controllers;
use Litepie\Outh2API\Http\Requests\OauthAppsRequest;
use Litepie\Outh2API\Models\OauthApps;

trait OauthAppsWorkflow {
	
    /**
     * Workflow controller function for oauth_apps.
     *
     * @param Model   $oauth_apps
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OauthAppsRequest $request, OauthApps $oauth_apps, $step)
    {

        try {

            $oauth_apps->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('outh2_a_p_i::oauth_apps.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/oauth_apps/oauth_apps/' . $oauth_apps->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/oauth_apps/oauth_apps/' . $oauth_apps->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for oauth_apps.
     *
     * @param Model   $oauth_apps
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(OauthApps $oauth_apps, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $oauth_apps->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('outh2_a_p_i::oauth_apps.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('outh2_a_p_i::admin.oauth_apps.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('outh2_a_p_i::admin.oauth_apps.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('outh2_a_p_i::admin.oauth_apps.message', $data)->render();

        }

    }
}