<?php

namespace Labrender\Outh2API\Policies;

use App\User;
use Labrender\Outh2API\Models\OauthApps;

class OauthAppsPolicy
{

    /**
     * Determine if the given user can view the oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function view(User $user, OauthApps $oauth_apps)
    {
        if ($user->canDo('outh2_a_p_i.oauth_apps.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $oauth_apps->user_id;
    }

    /**
     * Determine if the given user can create a oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('outh2_a_p_i.oauth_apps.create');
    }

    /**
     * Determine if the given user can update the given oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function update(User $user, OauthApps $oauth_apps)
    {
        if ($user->canDo('outh2_a_p_i.oauth_apps.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $oauth_apps->user_id;
    }

    /**
     * Determine if the given user can delete the given oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function destroy(User $user, OauthApps $oauth_apps)
    {
        if ($user->canDo('outh2_a_p_i.oauth_apps.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $oauth_apps->user_id;
    }

    /**
     * Determine if the given user can verify the given oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function verify(User $user, OauthApps $oauth_apps)
    {
        if ($user->canDo('outh2_a_p_i.oauth_apps.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('outh2_a_p_i.oauth_apps.verify') 
        && $user->is('manager')
        && $oauth_apps->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given oauth_apps.
     *
     * @param User $user
     * @param OauthApps $oauth_apps
     *
     * @return bool
     */
    public function approve(User $user, OauthApps $oauth_apps)
    {
        if ($user->canDo('outh2_a_p_i.oauth_apps.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
