<?php

namespace Labrender\Outh2API\Providers;

use Illuminate\Support\ServiceProvider;

class Outh2APIServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'outh2_a_p_i');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'outh2_a_p_i');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('outh2_a_p_i', function ($app) {
            return $this->app->make('Labrender\Outh2API\Outh2API');
        });

        // Bind OauthApps to repository
        $this->app->bind(
            'Labrender\Outh2API\Interfaces\OauthAppsRepositoryInterface',
            \Labrender\Outh2API\Repositories\Eloquent\OauthAppsRepository::class
        );

        $this->app->register(\Labrender\Outh2API\Providers\AuthServiceProvider::class);
        $this->app->register(\Labrender\Outh2API\Providers\EventServiceProvider::class);
        $this->app->register(\Labrender\Outh2API\Providers\RouteServiceProvider::class);
        // $this->app->register(\Labrender\Outh2API\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['outh2_a_p_i'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('labrender/outh2_a_p_i.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/outh2_a_p_i')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/outh2_a_p_i')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
