<?php

namespace Labrender\Outh2API\Workflow;

use Labrender\Outh2API\Models\OauthApps;
use Validator;

class OauthAppsValidator
{

    /**
     * Determine if the given oauth_apps is valid for complete status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function complete(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given oauth_apps is valid for verify status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function verify(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given oauth_apps is valid for approve status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function approve(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given oauth_apps is valid for publish status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function publish(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given oauth_apps is valid for archive status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function archive(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given oauth_apps is valid for unpublish status.
     *
     * @param OauthApps $oauth_apps
     *
     * @return bool / Validator
     */
    public function unpublish(OauthApps $oauth_apps)
    {
        return Validator::make($oauth_apps->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
